Construct a series name from variable components and retrieve the series
get_var.RdConstruct a series name from variable components and retrieve the series
Usage
get_var(ser_in, env = parent.frame())get_var.RdConstruct a series name from variable components and retrieve the series
get_var(ser_in, env = parent.frame())